<?php

namespace Ems\portalGestor\Controller;

use Ems\portalGestor\Service\AdmissaoService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class AdmissaoController {
    /** @var AdmissaoService */
    protected $admissaoService;

    public function __construct(
        AdmissaoService $admissaoService
    ) {
        $this->admissaoService = $admissaoService;
    }

    public function getVinculosNaoAprovados(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $cdOperador = (string) $row['CDOPERADOR'];

            $nrEstrutura = isset($row['NRESTRUTURAM']) ?
                (int) $row['NRESTRUTURAM'] :
                null;

            $admissoes = $this->admissaoService->getVinculosNaoAprovados(
                $nrOrg, $cdOperador, $nrEstrutura
            );

            $response->addDataSet(new DataSet('data', $admissoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCategoriasComAdmissaoVinculo(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $nrVinculo = (int) $row['NRVINCULOM'];

            $categorias = $this->admissaoService->getCategoriasComAdmissaoVinculo(
                $nrOrg, $nrVinculo
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getCategorias(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];

            $categorias = $this->admissaoService->getCategorias(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $categorias));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getTipos(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg = (int) $row['NRORG'];

            $tipos = $this->admissaoService->getTipos(
                $nrOrg
            );

            $response->addDataSet(new DataSet('data', $tipos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function downloadAdmissao(
        Request\Filter $request,
        Response       $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg   = (int) $row['NRORG'];
            $nrAnexo = (int) $row['NRANEXO'];

            $file = $this->admissaoService->downloadAdmissao(
                $nrOrg, $nrAnexo
            );

            $response->addDataSet(new DataSet('data', $file));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function saveAdmissao(
        Request\Row $request,
        Response       $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->admissaoService->saveAdmissao(
                $row
            );

            $dataset = [
                'success' => $success
            ];

            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
