<?php

namespace Ems\portalGestor\Controller;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\ORM\EntityManager;

use Ems\portalGestor\Service\OperadorService;

class OperadorController {

    public function __construct(EntityManager $entityManager, OperadorService $operadorService) {
        $this->entityManager    = $entityManager;
        $this->operadorService  = $operadorService;
    }

    public function getDadosOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $dadosOperador = $this->operadorService->getDadosOperador(
                $params['CDOPERADOR']
            );
            $response->addDataSet(new DataSet('getDadosOperador', $dadosOperador));
        } catch (\Exception $e) {
            $response->addMessage(new DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
        }
    }

    public function validaLoginVinculo(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $validaLogin = $this->operadorService->validaLoginVinculo(
                $params['NRVINCULOM'],
                $params['NRORG']
            );
            $response->addDataSet(new DataSet('validaLogin', array($validaLogin)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function validaLoginOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $params = $request->getParameters();
            $validaLoginOperador = $this->operadorService->validaLoginOperador(
                $params['CDOPERADOR']
            );
            $response->addDataSet(new DataSet('validaLoginOperador', array($validaLoginOperador)));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

}