<?php
namespace Teknisa\Model\Geral\Repositories;

use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use Teknisa\Model\Geral\Entities\Estruturam;

class Estruturah extends \Doctrine\ORM\EntityRepository {
    
    public function retornaEstruturaHistorico($nrorg, $nrestruturam, $dtmescompetenc){

	$params = array('nrestruturam' => $nrestruturam, 'nrorg'=>$nrorg, 'dtmescompetenc' => $dtmescompetenc);
    $estruturah =  '\Teknisa\Model\Geral\Entities\Estruturah';

$sql = <<<SQL
SELECT e FROM $estruturah e
WHERE e.nrorg = :nrorg
    AND e.nrestruturam = :nrestruturam    
    AND e.dtmescompetenc = 
    (SELECT MAX(ee.dtmescompetenc) FROM $estruturah ee
    WHERE ee.nrestruturam = e.nrestruturam
    AND ee.nrorg = e.nrorg
    AND ee.dtmescompetenc <= :dtmescompetenc
    )
SQL;
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result[0];
    }
    
    public function retornaEstruturaPorInscricaoTipoEstrutura($nrorg, $nrinscricao, $nrtipoestrutura, $dtmescompetenc){

	$params = array('nrinscricao' => $nrinscricao, 
	                'nrorg'=>$nrorg, 
	                'nrtipoestrutura' => $nrtipoestrutura,
	                'dtmescompetenc' => $dtmescompetenc);
	                
    $estruturah =  '\Teknisa\Model\Geral\Entities\Estruturah';
    $estruturam =  '\Teknisa\Model\Geral\Entities\Estruturam';

$sql = <<<SQL
SELECT em,eh 
FROM $estruturam em
LEFT JOIN $estruturah eh WITH eh.nrorg = em.nrorg
               AND eh.nrestruturam = em.nrestruturam
               AND eh.dtmescompetenc =  (SELECT MAX(ee.dtmescompetenc) FROM $estruturah ee
                                        WHERE ee.nrestruturam = eh.nrestruturam
                                        AND ee.nrorg = eh.nrorg
                                        AND ee.dtmescompetenc <= :dtmescompetenc)
WHERE em.nrorg = :nrorg
    AND ((eh.cdcnpjestrut = :nrinscricao AND eh.cdceiestrut IS NULL AND eh.cdcaepfestrut  IS NULL )
          OR eh.cdceiestrut = :nrinscricao
          OR eh.cdcaepfestrut = :nrinscricao)
    AND em.nrtipoestrutura = :nrtipoestrutura
SQL;
        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        return $result;
    }
    
    public function retornaEstruturaMatrizPorFilial($nrorg, $nrinscricao, $nrtipoestrutura, $dtmescompetenc){
        $db = \Setforms2\Shared\Registry::getEntityManagerConnection();

    	$params = array('P_NRINSCR' => $nrinscricao, 
    	                'P_NRORG'=>$nrorg, 
    	                'P_NRTIPOESTRUTLEGAL' => $nrtipoestrutura,
    	                'P_DTMESCOMPETENC' => $dtmescompetenc);

$sql = <<<SQL
SELECT EM.*,
       EH.*
  FROM ESTRUTURAM EM
  JOIN ESTRUTURAH EH ON EH.NRORG = EM.NRORG
                    AND EH.NRESTRUTURAM = EM.NRESTRUTURAM
                    AND EH.DTMESCOMPETENC = (SELECT MAX(ESTRUTURAH.DTMESCOMPETENC) FROM ESTRUTURAH 
                                              WHERE ESTRUTURAH.NRORG = EH.NRORG
                                                AND ESTRUTURAH.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
 WHERE EM.NRORG = :P_NRORG
   AND EM.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL
   AND EM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
   AND (EM.DTFIMVIGENCIA IS NULL OR EM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
   AND EH.CDCEIESTRUT IS NULL
   AND EH.CDCAEPFESTRUT  IS NULL
   AND SUBSTR(REPLACE(REPLACE(REPLACE(EH.CDCNPJESTRUT,'.'),'/'),'-'),1,8) = :P_NRINSCR
   AND SUBSTR(REPLACE(REPLACE(REPLACE(EH.CDCNPJESTRUT,'.'),'/'),'-'),9,4) = '0001'
SQL;
        $result = $db->fetchAll($sql,$params);
        return $result;
    }
    
    public function getFeriados($dtinicio, $dtfinal, $nrestruturam, $dtmescompetencia, $nrorg)
    {
        $db = \Setforms2\Shared\Registry::getEntityManagerConnection();
        
        $estruturah =  Repositories::ESTRUTURAH;
        $ocorcalendario = Repositories::OCORCALENDARIO;
        
        $params = [
                    'p_nrorg'=>$nrorg, 
                    'p_nrestruturam' => $nrestruturam, 
                    'p_dtmescompetenc' => $dtmescompetenc,
                  ];     

        $sql = <<<SQL
SELECT DISTINCT OCORCALENDARIO.DTCALENDARIO
FROM ESTRUTURAH
INNER JOIN OCORCALENDARIO
    ON OCORCALENDARIO.NRCALENDARIO = ESTRUTURAH.NRCALENDARIO
    AND OCORCALENDARIO.NRORG = ESTRUTURAH.NRORG
WHERE ESTRUTURAH.NRORG = $nrorg
    AND OCORCALENDARIO.DTCALENDARIO BETWEEN '$dtinicio' AND '$dtfinal'
    AND ESTRUTURAH.NRESTRUTURAM = $nrestruturam
    AND ESTRUTURAH.DTMESCOMPETENC = ( SELECT MAX(MAX_ESTRUTURAH.DTMESCOMPETENC)
                                    FROM ESTRUTURAH MAX_ESTRUTURAH
                                    WHERE MAX_ESTRUTURAH.DTMESCOMPETENC <= '$dtmescompetencia'
                                        AND MAX_ESTRUTURAH.NRORG = ESTRUTURAH.NRORG
                                        AND MAX_ESTRUTURAH.NRESTRUTURAM = ESTRUTURAH.NRESTRUTURAM)
SQL;
        $result = $db->fetchAll($sql,$params);
        
        if($result)
            return $result;
        else
            return array();
    }  
    
    public function getEstruturaPorNrInsc($nrorg, $dtmescompetenc, $prefixocnpj, $tpinsc){
        
        $estruturah =  '\Teknisa\Model\Geral\Entities\Estruturah';
        
        $sql = <<<SQL
SELECT eh 
  FROM $estruturah eh
 WHERE eh.nrorg = :p_nrorg
   AND ((substring(eh.cdcnpjestrut, 0, 12) = CONCAT(:p_prefixocnpj, '0001') AND :p_tpinsc = 1)
        OR (substring(eh.cdcnpjestrut, 0, 8) = :p_prefixocnpj AND :p_tpinsc = 2))
   AND eh.dtmescompetenc = (SELECT max(ehh.dtmescompetenc)
                              FROM $estruturah ehh
                             WHERE ehh.nrorg = eh.nrorg
                               AND ehh.nrestruturam = eh.nrestruturam
                               AND ehh.dtmescompetenc <= :p_dtmescompetenc)
SQL;
        
        $params = array(
            'p_prefixocnpj' => $prefixocnpj,
            'p_tpinsc' => $tpinsc,
            'p_dtmescompetenc' => $dtmescompetenc,
            'p_nrorg' => $nrorg
        );

        $result = $this->getEntityManager()->createQuery($sql)->execute($params);
        $result = ($result)?$result[0]:false;
        return $result;
    }

    
}